From fdd0f3b207785711663f48e0dd3414d90d1f2e86 Mon Sep 17 00:00:00 2001
From: Mike Frysinger <vapier@gentoo.org>
Date: Sat, 12 Nov 2011 14:24:08 -0500
Subject: [PATCH] use awk/sed instead of perl for creating header files

More systems should have awk/sed than perl.

Signed-off-by: Mike Frysinger <vapier@gentoo.org>
---
 libcap/Makefile |   20 ++++++++++++++++----
 1 files changed, 16 insertions(+), 4 deletions(-)

diff --git a/libcap/Makefile b/libcap/Makefile
index 4762c60..68845e0 100644
--- a/libcap/Makefile
+++ b/libcap/Makefile
@@ -24,6 +24,8 @@ OBJS=$(addsuffix .o, $(FILES))
 MINLIBNAME=$(MAJLIBNAME).$(MINOR)
 GPERF_OUTPUT = _caps_output.gperf
 CFLAGS += -fPIC
+AWK = awk
+SED = sed
 
 all: $(MINLIBNAME) $(STALIBNAME)
 
@@ -39,11 +41,21 @@ cap_names.h: _makenames
 	./_makenames > cap_names.h
 
 $(GPERF_OUTPUT): cap_names.list.h
-	perl -e 'print "struct __cap_token_s { const char *name; int index; };\n%{\nconst struct __cap_token_s *__cap_lookup_name(const char *, unsigned int);\n%}\n%%\n"; while ($$l = <>) { $$l =~ s/[\{\"]//g; $$l =~ s/\}.*// ; print $$l; }' < $< | gperf --ignore-case --language=ANSI-C --readonly --null-strings --global-table --hash-function-name=__cap_hash_name --lookup-function-name="__cap_lookup_name" -c -t -m20 $(INDENT) > $@
+	(printf "%b" "struct __cap_token_s { const char *name; int index; };\n%{\nconst struct __cap_token_s *__cap_lookup_name(const char *, unsigned int);\n%}\n%%\n"; \
+	$(SED) -e 's:["{}]::g' -e 's:,$$::' $<) | \
+	gperf \
+		--ignore-case \
+		--language=ANSI-C \
+		--readonly \
+		--null-strings \
+		--global-table \
+		--hash-function-name=__cap_hash_name \
+		--lookup-function-name="__cap_lookup_name" \
+		-c -t -m20 $(INDENT) > $@
 
-cap_names.list.h: Makefile $(KERNEL_HEADERS)/linux/capability.h
-	@echo "=> making $@ from $(KERNEL_HEADERS)/linux/capability.h"
-	perl -e 'while ($$l=<>) { if ($$l =~ /^\#define[ \t](CAP[_A-Z]+)[ \t]+([0-9]+)\s+$$/) { $$tok=$$1; $$val=$$2; $$tok =~ tr/A-Z/a-z/; print "{\"$$tok\",$$val},\n"; } }' $(KERNEL_HEADERS)/linux/capability.h | fgrep -v 0x > $@
+cap_names.list.h: $(KERNEL_HEADERS)/linux/capability.h Makefile
+	@echo "=> making $@ from $<"
+	$(AWK) '($$0 ~ /^#define[[:space:]]+CAP[_A-Z]+[[:space:]]+[0-9]+[[:space:]]*$$/) { printf "{\"%s\",%s},\n", tolower($$2), $$3 }' $< > $@
 
 $(STALIBNAME): $(OBJS)
 	$(AR) rcs $@ $^
-- 
1.7.6.1

